Connection class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(String sql, {Params? params}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare(String sql) Future<Statement>
query(String sql, {Params? params}) Future<List<Map<String, dynamic>>>
toString() String
A string representation of this object.
inherited
transaction({TransactionBehavior behavior = turso.TransactionBehavior.deferred}) Future<Transaction>

Operators

operator ==(Object other) bool
The equality operator.
inherited